# we don't want the auto require to add require on /usr/bin/ocaml
%global __requires_exclude %{_bindir}/ocaml

Name:           menhir
Version:        20240715
Release:        %mkrel 2
Summary:        Menhir is a LR(1) parser generator for OCaml
License:        LGPL and QPL with static compilation exception
Group:          Development/OCaml
URL:            https://pauillac.inria.fr/~fpottier/menhir/
Source0:        https://gitlab.inria.fr/fpottier/menhir/-/archive/%{version}/menhir-%{version}.tar.bz2
BuildRequires:  ocaml
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-findlib

Provides:       ocaml-menhir = %{version}-%{release}

%description
Menhir is a LR(1) parser generator for OCaml. It is mostly compatible
with the standard ocamlyacc and has the following enhancements:

- it accepts LR(1) grammars,
- it offers parameterized nonterminal symbols as well as a library of
  standard definitions,
- it explains conflicts in terms of the grammar,
- it allows grammar specifications to be split over multiple files and
  parametrized by OCaml modules,
- it produces reentrant parsers.

%package     -n ocaml-menhirlib
Summary:        Runtime library for parsers produced by Menhir
# The library is LGPL-2.0-only with a linking exception.
License:        LGPL-2.0-only WITH OCaml-LGPL-linking-exception

%description -n ocaml-menhirlib
This package contains the runtime library for parsers produced by Menhir.

%package     -n ocaml-menhirlib-devel
Summary:        Development files for ocaml-menhirlib
# The library is LGPL-2.0-only with a linking exception.
License:        LGPL-2.0-only WITH OCaml-LGPL-linking-exception
Requires:       ocaml-menhirlib%{?_isa} = %{version}-%{release}

%description -n ocaml-menhirlib-devel
This ocaml-menhirlib-devel package contains libraries and signature
files for building applications with a parser produced by Menhir.

%prep
%autosetup

%build
%dune_build

%install
%dune_install -s

# We do not install *.ml files by default, but this one is needed
cp -p _build/default/lib/pack/menhirLib.ml %{buildroot}%{ocamldir}/menhirLib

rm -rf %{buildroot}%{ocamldir}/coq-menhirlib/

%files
%doc doc/manual.html doc/manual.pdf doc/manual*.png
%license LICENSE
%{_bindir}/menhir
%{_mandir}/man1/menhir.1*
%{ocamldir}/menhir/
%{ocamldir}/menhirCST/
%{ocamldir}/menhirSdk/

%files -n ocaml-menhirlib -f .ofiles-menhirLib
%license LICENSE

%files -n ocaml-menhirlib-devel -f .ofiles-menhirLib-devel
%{ocamldir}/menhirLib/menhirLib.ml


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 20240715-2.mga10
+ Revision: 2250906
- Mageia 10 Mass Rebuild

* Sun Apr 06 2025 pterjan <pterjan> 20240715-1.mga10
+ Revision: 2174021
- Update to 20240715

* Sat Jan 14 2023 daviddavid <daviddavid> 20220210-1.mga9
+ Revision: 1932820
- new version: 20220210

* Thu May 19 2022 pterjan <pterjan> 20181113-10.mga9
+ Revision: 1858893
- Rebuild for OCaml 4.14

* Tue Mar 29 2022 umeabot <umeabot> 20181113-9.mga9
+ Revision: 1832443
- Mageia 9 Mass Rebuild

* Tue Oct 12 2021 tv <tv> 20181113-8.mga9
+ Revision: 1750711
- Rebuild for ocaml 4.13.1

* Wed Mar 03 2021 tv <tv> 20181113-6.mga9
+ Revision: 1696547
- rebuild for ocaml-4.2-12

* Sun Jan 10 2021 pterjan <pterjan> 20181113-5.mga8
+ Revision: 1670424
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 20181113-4.mga8
+ Revision: 1551351
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 20181113-3.mga8
+ Revision: 1543445
- Mageia 8 Mass Rebuild

* Sun Jan 19 2020 tv <tv> 20181113-2.mga8
+ Revision: 1481569
- rebuild for ocaml-4.10

* Fri Nov 16 2018 daviddavid <daviddavid> 20181113-1.mga7
+ Revision: 1330076
- new version: 20181113
- update Source URL

* Tue Oct 23 2018 tv <tv> 20180905-2.mga7
+ Revision: 1324184
- rebuild with ocaml-4.07.1

* Fri Sep 28 2018 daviddavid <daviddavid> 20180905-1.mga7
+ Revision: 1309401
- new version: 20180905

* Thu Aug 23 2018 daviddavid <daviddavid> 20180530-1.mga7
+ Revision: 1253540
- new version: 20180530
+ kekepower <kekepower>
- Use __make

* Sun Jan 28 2018 daviddavid <daviddavid> 20171222-1.mga7
+ Revision: 1197492
- new version: 20171222
- provides ocaml-menhir

* Sun Nov 26 2017 tv <tv> 20171013-1.mga7
+ Revision: 1179889
- new release
- BR ocaml-ocamlbuild
- rebuild for new ocaml

* Sun Sep 25 2016 pterjan <pterjan> 20151112-2.mga6
+ Revision: 1056218
- Rebuild for fix in ocaml

* Mon Feb 01 2016 pterjan <pterjan> 20151112-1.mga6
+ Revision: 930644
- Update to 20151112

* Wed Oct 15 2014 umeabot <umeabot> 20140422-4.mga5
+ Revision: 747316
- Second Mageia 5 Mass Rebuild

* Mon Sep 22 2014 malo <malo> 20140422-3.mga5
+ Revision: 714289
- fix requires

* Tue Sep 16 2014 umeabot <umeabot> 20140422-2.mga5
+ Revision: 682356
- Mageia 5 Mass Rebuild

* Sun Sep 14 2014 malo <malo> 20140422-1.mga5
+ Revision: 675200
- update to 20140422

* Sat Oct 19 2013 umeabot <umeabot> 20130911-3.mga4
+ Revision: 535765
- Mageia 4 Mass Rebuild

* Fri Sep 20 2013 malo <malo> 20130911-2.mga4
+ Revision: 482505
- fix PREFIX during install

* Fri Sep 20 2013 malo <malo> 20130911-1.mga4
+ Revision: 482434
- new version 20130911

* Sun Jun 09 2013 malo <malo> 20130116-1.mga4
+ Revision: 441325
- new version 20130116

* Sat Jan 12 2013 umeabot <umeabot> 20120123-5.mga3
+ Revision: 359954
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 19 2012 malo <malo> 20120123-4.mga3
+ Revision: 308239
- rebuild for ocaml-4.0.1

* Mon Oct 01 2012 blue_prawn <blue_prawn> 20120123-3.mga3
+ Revision: 301096
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 20120123-2.mga3
+ Revision: 300494
- new rpm group for ocaml

* Tue Aug 21 2012 blue_prawn <blue_prawn> 20120123-1.mga3
+ Revision: 282996
- updated to last version 20120123

* Thu Jan 12 2012 blue_prawn <blue_prawn> 20120109-1.mga2
+ Revision: 195177
- added req ocaml-findlib and fixed PREFIX in %%build
- fixed prefix
- corrected dest lib dir
- imported package menhir

